dict_jp_cn = {
    "わかばシューター": "新叶射击枪",
    "スプラシューター": "斯普拉射击枪",
    "N-ZAP85": "N-ZAP85",
    "シャープマーカー": "窄域标记枪",
    "ボールドマーカー": "广域标记枪",
    "プロモデラーMG": "专业模型枪MG",
    "プライムシューター": "顶尖射击枪",
    ".52ガロン": ".52加仑",
    ".96ガロン": ".96加仑",
    "ジェットスイーパー": "喷射清洁枪",
    "L3リールガン": "L3卷线枪",
    "H3リールガン": "H3卷线枪",
    "ボトルガイザー": "开瓶喷泉枪",
    "スプラローラー": "斯普拉滚筒",
    "ダイナモローラー": "电动马达滚筒",
    "ヴァリアブルローラー": "可变式滚筒",
    "カーボンローラー": "碳纤维滚筒",
    "スプラチャージャー": "斯普拉蓄力狙击枪",
    "スプラスコープ": "斯普拉准星枪",
    "スクイックリンα": "鱿快洁α",
    "14式竹筒銃・甲": "14式竹筒枪·甲",
    "ソイチューバー": "高压油管枪",
    "リッター4K": "公升4K",
    "4Kスコープ": "4K准星枪",
    "バケットスロッシャー": "飞溅泼桶",
    "ヒッセン": "洗笔筒",
    "スクリュースロッシャー": "回旋泼桶",
    "オーバーフロッシャー": "满溢泡澡泼桶",
    "エクスプロッシャー": "爆炸泼桶",
    "バレルスピナー": "桶装旋转枪",
    "スプラスピナー": "斯普拉旋转枪",
    "ハイドラント": "消防栓旋转枪",
    "クーゲルシュライバー": "圆珠笔",
    "ノーチラス47": "鹦鹉螺号47",
    "スプラマニューバー": "斯普拉机动枪",
    "デュアルスイーパー": "双重清洁枪",
    "クアッドホッパーブラック": "四重弹跳手枪 黑",
    "ケルビン525": "开尔文525",
    "スパッタリー": "溅镀枪",
    "パラシェルター": "遮阳防空伞",
    "キャンピングシェルター": "露营防空伞",
    "スパイガジェット": "特工配件",
    "ホットブラスター": "火热爆破枪",
    "ロングブラスター": "远距离爆破枪",
    "ノヴァブラスター": "新星爆破枪",
    "クラッシュブラスター": "冲涂爆破枪",
    "ラピッドブラスター": "快速爆破枪",
    "Rブラスターエリート": "快速爆破枪 精英",
    "パブロ": "巴勃罗",
    "ホクサイ": "北斋",
    "トライストリンガー": "三发猎鱼弓",
    "LACT-450": "LACT-450",
    "ライブワイパー": "雨刷刮水刀",
    "ドライブワイパー": "工作刮水刀",
    "プロモデラーRG": "专业模型枪RG",
    "バケットスロッシャーデコ": "飞溅泼桶 装饰",
    "パブロ・ヒュー": "巴勃罗・新艺术",
    "スパッタリー・ヒュー": "溅镀枪・新艺术",
    "プライムシューターコラボ": "顶尖射击枪 联名",
    "ノヴァブラスターネオ": "新星爆破枪 新型",
    "もみじシューター": "枫叶射击枪",
    "カーボンローラーデコ": "碳纤维滚筒 装饰",
    "スプラシューターコラボ": "斯普拉射击枪 联名",
    "スペースシューター": "太空射击枪",
    "スプラスピナーコラボ": "斯普拉旋转枪 联名",
    "R-PEN/5H": "R-PEN/5H",
    "ワイドローラー": "宽滚筒",
    "ランダム": "随机",
    "海女美術大学": "海女美术大学",
    "チョウザメ造船": "鲟鱼造船厂",
    "ザトウマーケット": "座头购物中心",
    "スメーシーワールド": "醋饭海洋世界",
    "マサバ海峡大橋": "真鲭跨海大桥",
    "キンメダイ美術館": "金眼鲷美术馆",
    "マヒマヒリゾート＆スパ": "鬼头刀SPA度假区",
    "ユノハナ大渓谷": "温泉花大峡谷",
    "ゴンズイ地区": "鳗鲶区",
    "ヤガラ市場": "烟管鱼市场",
    "マテガイ放水路": "竹蛏疏洪道",
    "ナメロウ金属": "鱼肉碎金属",
    "クサヤ温泉": "臭鱼干温泉",
    "ヒラメが丘団地": "比目鱼住宅区",
    "難破船ドン・ブラコ": "漂浮落难船",
    "ムニ・エール海洋発電所": "麦年海洋发电所",
    "シェケナダム": "鲑坝",
    "アラマキ砦": "新卷堡"
}


def translate(text) -> str:
    value = dict_jp_cn.get(text)
    return value




import json

from datetime import datetime

from typing import List

from ..model import Bankara, FestStage, Regular, SalmonRun
from ..utils.common import fetch
from ..utils.api_parse import *


def parse_time(iso_from) -> str:
    time = datetime.fromisoformat(iso_from)
    return str(time.month) + '.' + str(time.day) + ' ' + str(time.hour - 1) + ':00'


def bankara_to_string(start, end, rule, stage1, stage2) -> str:
    start = parse_time(start)
    end = parse_time(end)
    return Bankara(start, end, rule, stage1, stage2).to_string()


def regular_to_string(start, end, stage1, stage2) -> str:
    start = parse_time(start)
    end = parse_time(end)
    return Regular(start, end, stage1, stage2).to_string()


def fest_to_string(start, end, stage1, stage2, tricolor) -> str:
    start = parse_time(start)
    end = parse_time(end)
    return FestStage(start, end, stage1, stage2, tricolor).to_string()


def salmon_run_to_string(start, end, stage, weapon1, weapon2, weapon3, weapon4) -> str:
    start = parse_time(start)
    end = parse_time(end)
    return SalmonRun(start, end, stage, weapon1, weapon2, weapon3, weapon4).to_string()


async def list_stage(stage_type, time) -> List[str]:
    url = baseUrl + parse_p1(stage_type) + parse_p2(time)
    results = json.loads(await fetch(url))['results']
    data: List[str] = []
    n = len(results)

    if stage_type == 'regular':
        for (index, result) in enumerate(results):
            data.append(
                regular_to_string(result['start_time'], result['end_time'], result['stages'][0]['name'],
                                  result['stages'][1]['name']))
            if n > 1 and index < 2:
                data.append('\n\n')
            if index == 2:
                break

    elif stage_type == 'salmon_run':
        for (index, result) in enumerate(results):
            weapons = [weapon['name'] for weapon in result['weapons']]
            data.append(
                salmon_run_to_string(result['start_time'], result['end_time'], result['stage']['name'], weapons[0],
                                     weapons[1], weapons[2], weapons[3]))
            if n > 1 and index < 2:
                data.append('\n\n')
            if index == 2:
                break

    elif stage_type == 'fest':
        for (index, result) in enumerate(results):
            if not result['is_tricolor']:
                result['tricolor_stage'] = ''
            data.append(
                fest_to_string(result['start_time'], result['end_time'], result['stages'][0]['name'],
                               result['stages'][1]['name'],
                               result['tricolor_stage']))
            if n > 1 and index < 2:
                data.append('\n\n')
            if index == 2:
                break

    else:
        for (index, result) in enumerate(results):
            data.append(
                bankara_to_string(result['start_time'], result['end_time'], result['rule']['key'],
                                  result['stages'][0]['name'], result['stages'][1]['name']))
            if n > 1 and index < 2:
                data.append('\n\n')
            if index == 2:
                break

    return data



from .utils.translate import translate
from .utils.constants import get_rule


class Bankara(object):
    def __init__(self, start, end, rule, stage1, stage2) -> None:
        self.start = start
        self.end = end
        self.rule = get_rule(rule)
        self.stage1 = translate(stage1)
        self.stage2 = translate(stage2)

    def to_string(self) -> str:
        return self.start + ' - ' + self.end + ' ' + self.rule + '\n' + self.stage1 + ' ' + self.stage2


class FestStage(object):
    def __init__(self, start, end, stage1, stage2, tricolor) -> None:
        self.start = start
        self.end = end
        self.stage1 = translate(stage1)
        self.stage2 = translate(stage2)
        self.tricolor = translate(tricolor)

    def to_string(self) -> str:
        return self.start + ' - ' + self.end + '\n' + self.stage1 + ' ' + self.stage2


class Regular(object):
    def __init__(self, start, end, stage1, stage2) -> None:
        self.start = start
        self.end = end
        self.stage1 = translate(stage1)
        self.stage2 = translate(stage2)

    def to_string(self) -> str:
        return self.start + ' - ' + self.end + '\n' + self.stage1 + ' ' + self.stage2


class SalmonRun(object):
    def __init__(self, start, end, stage, weapon1, weapon2, weapon3, weapon4) -> None:
        self.start = start
        self.end = end
        self.stage = translate(stage)
        self.weapon1 = translate(weapon1)
        self.weapon2 = translate(weapon2)
        self.weapon3 = translate(weapon3)
        self.weapon4 = translate(weapon4)

    def to_string(self) -> str:
        return self.start + ' - ' + self.end + '\n' + self.stage + '\n' + self.weapon1 + ' ' + self.weapon2 + '\n' + self.weapon3 + ' ' + self.weapon4



import nonebot

from nonebot import on_command, logger
from nonebot.adapters.onebot.v11 import Bot, MessageEvent

from .utils.common import ServiceException
from .services.stage_service import list_stage

__plugin_meta__ = nonebot.plugin.PluginMetadata(
    name='熊老板-喷喷喷场地信息查询',
    description='一个查询斯普拉遁3场地信息的插件',
    usage='用法： 对我说 “reg(涂地)/chal(真格挑战)/open(真格区域)/baito(打工)/fest(祭典)/x(x段) + (可选)now/next\n例如‘baito‘直接查询打工的场地；’baito now‘查询现在打工的场地',
    extra={'version': '1.0.4'}
)

baito = on_command('baito', aliases={'打工'}, priority=2, block=True)


@baito.handle()
async def _(bot: Bot, event: MessageEvent):
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)

    if n == 1:
        result_str = '以下是接下来的鲑鱼跑场地：\n' + await request('salmon_run', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的鲑鱼跑场地：\n' + await request('salmon_run', args[1])
    elif args[1] == 'next':
        result_str = '接下来的鲑鱼跑场地：\n' + await request('salmon_run', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await baito.send(message='快来给我打工，成为传说打工人吧，少年！\n' + result_str, at_sender=True)


regular_stage = on_command('reg', aliases={'涂地'}, priority=2, block=True)


@regular_stage.handle()
async def _(bot: Bot, event: MessageEvent):
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)

    if n == 1:
        result_str = '以下是接下来的涂地场地：\n' + await request('regular', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的涂地场地：\n' + await request('regular', args[1])
    elif args[1] == 'next':
        result_str = '接下来的涂地场地：\n' + await request('regular', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await regular_stage.send(message=result_str, at_sender=True)


open_stage = on_command('open', aliases={'开放'}, priority=2, block=True)


@open_stage.handle()
async def _(bot: Bot, event: MessageEvent):
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)

    if n == 1:
        result_str = '以下是接下来的真格开放场地：\n' + await request('open', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的真格开放场地：\n' + await request('open', args[1])
    elif args[1] == 'next':
        result_str = '接下来的真格开放场地：\n' + await request('open', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await open_stage.send(message=result_str, at_sender=True)


challenge_stage = on_command('chal', aliases={'挑战'}, priority=2, block=True)


@challenge_stage.handle()
async def _(bot: Bot, event: MessageEvent):
    logger.info('message => ' + event.get_message().extract_plain_text())
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)
    if n == 1:
        result_str = '以下是接下来的真格挑战场地：\n' + await request('challenge', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的真格挑战场地：\n' + await request('challenge', args[1])
    elif args[1] == 'next':
        result_str = '接下来的真格挑战场地：\n' + await request('challenge', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await challenge_stage.send(message=result_str, at_sender=True)


x_stage = on_command('x', aliases={'x段赛'}, priority=2, block=True)


@x_stage.handle()
async def _(bot: Bot, event: MessageEvent):
    logger.info('message => ' + event.get_message().extract_plain_text())
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)
    if n == 1:
        result_str = '以下是接下来的x段赛场地：\n' + await request('x', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的x段赛场地：\n' + await request('x', args[1])
    elif args[1] == 'next':
        result_str = '接下来的x段赛场地：\n' + await request('x', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await x_stage.send(message=result_str, at_sender=True)


fest_stage = on_command('fest', aliases={'祭典'}, priority=2, block=True)


@fest_stage.handle()
async def _(bot: Bot, event: MessageEvent):
    logger.info('message => ' + event.get_message().extract_plain_text())
    args = event.get_message().extract_plain_text().split(' ')
    n = len(args)
    if n == 1:
        result_str = '以下是接下来的祭典场地：\n' + await request('fest', 'schedule')
    elif args[1] == 'now':
        result_str = '现在的祭典场地：\n' + await request('fest', args[1])
    elif args[1] == 'next':
        result_str = '接下来的祭典场地：\n' + await request('fest', args[1])
    else:
        result_str = '你发错命令了！多来打工锻炼锻炼吧！'

    await fest_stage.send(message=result_str, at_sender=True)


help_command = on_command('help', priority=2, block=True)


@help_command.handle()
async def _(bot: Bot, event: MessageEvent):
    text = get_help_text()
    await help_command.send(message=text, at_sender=True)


async def request(name, time):
    try:
        results = await list_stage(name, time)
        result_str = ''
        for result in results:
            result_str += result
        return result_str
    except ServiceException as e:
        results = e.message


def parse_time(time):
    if time == 'now' or time == 'next':
        return time
    elif time == 'plan':
        return 'schedule'
    else:
        return None


def get_help_text() -> str:
    with open("./src/plugins/splat3_stage_helper/help.txt", 'r', encoding="utf-8") as f:
        help_text = f.read()
    return help_text




# baseUrl
baseUrl = 'https://spla3.yuu26.com/api'
# p1
regular = '/regular'
bankara_challenge = '/bankara-challenge'
bankara_open = '/bankara-open'
fest = '/fest'
x = '/x'
samonrun = '/coop-grouping'
# p2
now = '/now'
next = '/next'
schedule = '/schedule'

rules = {"LOFT": "真格塔楼", "GOAL": "真格鱼虎", "AREA": "真格区域", "CLAM": "真格蛤蜊"}


def get_rule(key):
    return rules.get(key)




from httpx import AsyncClient, HTTPError

from nonebot import logger


class ServiceException(Exception):
    'Base of exceptions thrown by the service side'

    def __init__(self, message: str) -> None:
        super().__init__(message)

    @property
    def message(self) -> str:
        return self.args[0]


async def fetch(uri: str) -> str:
    async with AsyncClient(headers={'User-Agent': 'box-s-ville.luciabot'}) as client:
        try:
            res = await client.get(uri)
            res.raise_for_status()
        except HTTPError as e:
            logger.exception(e)
            raise ServiceException('API 服务目前不可用')
        return res.text



from ..utils.constants import *


def parse_p1(stage_type) -> str:
    if stage_type == 'regular':
        return regular
    elif stage_type == 'open':
        return bankara_open
    elif stage_type == 'challenge':
        return bankara_challenge
    elif stage_type == 'fest':
        return fest
    elif stage_type == 'x':
        return x
    else:
        return samonrun


def parse_p2(time) -> str:
    if time == 'now':
        return now
    elif time == 'next':
        return next
    else:
        return schedule
